@@ -3,6 +3,7 @@
 import pandas as pd
 from pandas.api.types import is_numeric_dtype
 from functools import reduce
+import warnings
 
 
 @pd.api.extensions.register_dataframe_accessor("stb")
@@ -75,6 +76,9 @@ class SideTableAccessor:
         if thresh > 100:
             raise AttributeError('Thresh must be <= 100')
 
+        if thresh <= 1:
+            warnings.warn(f'thresh should be expressed as a percentage. Did you mean {int(thresh*100)}?')
+
         # Determine aggregation (counts or summation) for each item in column
 
         # TODO: NaNs need to be handled better. Wait for pandas 1.1
@@ -175,7 +179,11 @@ class SideTableAccessor:
                            'percent']].sort_values(by=['missing'],
                                                    ascending=False)
         if style:
-            format_dict = {'percent': '{:.2f}%', 'total': '{0:,.0f}'}
+            format_dict = {
+                'percent': '{:.2f}%',
+                'total': '{0:,.0f}',
+                'missing': '{0:,.0f}'
+            }
             return results.style.format(format_dict)
         else:
             return results
@@ -236,11 +244,13 @@ class SideTableAccessor:
             if exclude is not None:
                 msg = "exclude must be None when include is 'all'"
                 raise ValueError(msg)
-            cols_to_use = self._obj.columns
+            # Filter out columns that are completely null
+            cols_to_use = self._obj.columns[~self._obj.isna().all()]
 
         # Default is to include all columns
         elif (include is None) and (exclude is None):
-            cols_to_use = self._obj.columns
+            # Filter out completely null columns
+            cols_to_use = self._obj.columns[~self._obj.isna().all()]
 
         # Pass the include and exclude values to select_dtypes
         else:
